# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_mctl_global_optspecs
	string join \n c/config= h/help V/version
end

function __fish_mctl_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_mctl_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_mctl_using_subcommand
	set -l cmd (__fish_mctl_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c mctl -n "__fish_mctl_needs_command" -s c -l config -d 'Additional configuration file to load' -r -F
complete -c mctl -n "__fish_mctl_needs_command" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_needs_command" -s V -l version -d 'Print version'
complete -c mctl -n "__fish_mctl_needs_command" -f -a "secret" -d 'Manages the secrets'
complete -c mctl -n "__fish_mctl_needs_command" -f -a "utils" -d 'Utility functions like shell completions'
complete -c mctl -n "__fish_mctl_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and not __fish_seen_subcommand_from edit cat rotate help" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and not __fish_seen_subcommand_from edit cat rotate help" -f -a "edit" -d 'Edits a secret'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and not __fish_seen_subcommand_from edit cat rotate help" -f -a "cat" -d 'Cats a secret'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and not __fish_seen_subcommand_from edit cat rotate help" -f -a "rotate"
complete -c mctl -n "__fish_mctl_using_subcommand secret; and not __fish_seen_subcommand_from edit cat rotate help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from edit" -l allow-empty -d 'Allow a secret to be empty'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from edit" -l stdin -d 'Read the secret from stdin'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from cat" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from rotate" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from help" -f -a "edit" -d 'Edits a secret'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from help" -f -a "cat" -d 'Cats a secret'
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from help" -f -a "rotate"
complete -c mctl -n "__fish_mctl_using_subcommand secret; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and not __fish_seen_subcommand_from completion manpages help" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and not __fish_seen_subcommand_from completion manpages help" -f -a "completion" -d 'Generates shell completions for the given shell'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and not __fish_seen_subcommand_from completion manpages help" -f -a "manpages" -d 'Generates the Man pages for the program'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and not __fish_seen_subcommand_from completion manpages help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and __fish_seen_subcommand_from completion" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and __fish_seen_subcommand_from manpages" -s h -l help -d 'Print help'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and __fish_seen_subcommand_from help" -f -a "completion" -d 'Generates shell completions for the given shell'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and __fish_seen_subcommand_from help" -f -a "manpages" -d 'Generates the Man pages for the program'
complete -c mctl -n "__fish_mctl_using_subcommand utils; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand help; and not __fish_seen_subcommand_from secret utils help" -f -a "secret" -d 'Manages the secrets'
complete -c mctl -n "__fish_mctl_using_subcommand help; and not __fish_seen_subcommand_from secret utils help" -f -a "utils" -d 'Utility functions like shell completions'
complete -c mctl -n "__fish_mctl_using_subcommand help; and not __fish_seen_subcommand_from secret utils help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c mctl -n "__fish_mctl_using_subcommand help; and __fish_seen_subcommand_from secret" -f -a "edit" -d 'Edits a secret'
complete -c mctl -n "__fish_mctl_using_subcommand help; and __fish_seen_subcommand_from secret" -f -a "cat" -d 'Cats a secret'
complete -c mctl -n "__fish_mctl_using_subcommand help; and __fish_seen_subcommand_from secret" -f -a "rotate"
complete -c mctl -n "__fish_mctl_using_subcommand help; and __fish_seen_subcommand_from utils" -f -a "completion" -d 'Generates shell completions for the given shell'
complete -c mctl -n "__fish_mctl_using_subcommand help; and __fish_seen_subcommand_from utils" -f -a "manpages" -d 'Generates the Man pages for the program'
